@@ -63,6 +63,8 @@ __all__ = [
     "create_guid",
     "segments_to_local_points",
     "zip_dir",
+    "replace_nodes_by_tol",
+    "replace_node",
 ]
 
 
@@ -373,9 +375,9 @@ def is_point_inside_bbox(p, bbox, tol=1e-3):
     :return:
     """
     if (
-        bbox[0][0] - tol < p[0] < bbox[0][1] + tol
-        and bbox[1][0] - tol < p[1] < bbox[1][1] + tol
-        and bbox[2][0] - tol < p[2] < bbox[2][1] + tol
+        bbox[0][0][0] - tol < p[0] < bbox[0][1][0] + tol
+        and bbox[1][0][1] - tol < p[1] < bbox[1][1][1] + tol
+        and bbox[2][0][2] - tol < p[2] < bbox[2][1][2] + tol
     ):
         return True
     else:
@@ -1760,19 +1762,19 @@ class SIZE_UNIT:
 
 
 def convert_unit(size_in_bytes, unit):
-    """ Convert the size from bytes to other units like KB, MB or GB"""
+    """Convert the size from bytes to other units like KB, MB or GB"""
     if unit == SIZE_UNIT.KB:
         return size_in_bytes / 1024
     elif unit == SIZE_UNIT.MB:
-        return size_in_bytes / (1024 * 1024)
+        return size_in_bytes / (1024 ** 2)
     elif unit == SIZE_UNIT.GB:
-        return size_in_bytes / (1024 * 1024 * 1024)
+        return size_in_bytes / (1024 ** 3)
     else:
         return size_in_bytes
 
 
 def get_file_size(file_name, size_type=SIZE_UNIT.MB):
-    """ Get file in size in given unit like KB, MB or GB"""
+    """Get file in size in given unit like KB, MB or GB"""
     size = os.path.getsize(file_name)
     return convert_unit(size, size_type)
 
@@ -2022,23 +2024,22 @@ def get_current_user():
     return getpass.getuser()
 
 
-def get_list_of_files(dir_name, file_ext=None, strict=False):
+def get_list_of_files(dir_path, file_ext=None, strict=False):
     """
     Get a list of file and sub directories for a given directory
 
-    :param dir_name: Parent directory in which the recursive search for files will take place
+    :param dir_path: Parent directory in which the recursive search for files will take place
     :param file_ext: File extension
     :param strict: If True the function raiser errors when no files are found.
-    :return:
+    :return: list of all found files
     """
-
-    list_of_file = os.listdir(dir_name)
-    all_files = list()
+    all_files = []
+    list_of_file = os.listdir(dir_path)
 
     # Iterate over all the entries
     for entry in list_of_file:
         # Create full path
-        full_path = os.path.join(dir_name, entry)
+        full_path = os.path.join(dir_path, entry)
         # If entry is a directory then get the list of files in this directory
         if os.path.isdir(full_path):
             all_files = all_files + get_list_of_files(full_path)
@@ -2048,8 +2049,8 @@ def get_list_of_files(dir_name, file_ext=None, strict=False):
     if file_ext is not None:
         all_files = [f for f in all_files if f.endswith(file_ext)]
 
-    if not all_files:
-        msg = f'Files with "{file_ext}"-extension is not found in "{dir_name}" or any sub-folder.'
+    if len(all_files) == 0:
+        msg = f'Files with "{file_ext}"-extension is not found in "{dir_path}" or any sub-folder.'
         if strict:
             raise FileNotFoundError(msg)
         else:
@@ -2885,3 +2886,67 @@ def compute_minimal_distance_between_shapes(shp1, shp2):
     logging.info("Minimal distance between shapes: ", dss.Value())
 
     return dss
+
+
+def replace_node(fem, old, new):
+    """
+
+    :param fem: ada.fem
+    :param old:
+    :param new:
+    :type fem: ada.fem.FEM
+    :type old: ada.Node
+    :type new: ada.Node
+    """
+
+    for elem in old.refs.copy():
+        # assert isinstance(ref, ada.fem.Elem)
+        try:
+            ref_index = elem.nodes.index(old)
+        except ValueError:
+            return
+        elem.nodes.pop(ref_index)
+
+        if new.id not in [e.id for e in elem.nodes]:
+            elem.nodes.insert(ref_index, new)
+
+        if len(elem.nodes) < 2:
+            fem.elements.remove_elements_by_id(elem.id)
+            old.refs.pop(old.refs.index(elem))
+            logging.error(f"Element removed due to coinciding nodes. Elem id {elem.id}")
+        elif len(elem.nodes) == (len(elem.edges_seq) - 1):
+            elem.change_type(len(elem.nodes))
+
+
+def replace_nodes_by_tol(fem, decimals=0, tol=1e-4):
+    """
+
+    :param fem:
+    :param decimals:
+    :param tol:
+    :type fem: ada.fem.FEM
+    """
+
+    def rounding(vec, decimals_):
+        return np.around(vec, decimals=decimals_)
+
+    def n_is_most_precise(node, other_nodes_, decimals_=0):
+        most_precise = [np.array_equal(node.p, rounding(node.p, decimals_)) for node in [n] + other_nodes_]
+
+        if most_precise[0] and not np.all(most_precise[1:]):
+            return True
+        elif not most_precise[0] and np.any(most_precise[1:]):
+            return False
+        elif decimals_ == 10:
+            logging.error(f"Recursion started at 0 decimals, but are now at {decimals_} decimals. Will proceed with n.")
+            return True
+        else:
+            return n_is_most_precise(node, other_nodes_, decimals_ + 1)
+
+    for n in fem.nodes:
+        nearby_nodes = fem.nodes.get_by_volume(n.p, tol=tol)
+        other_nodes = list(filter(lambda x: x != n, nearby_nodes))
+        if len(other_nodes) > 0:
+            if n_is_most_precise(n, other_nodes, decimals):
+                for other_node in other_nodes:
+                    replace_node(fem, other_node, n)
