@@ -128,6 +128,22 @@ class FemElements:
         p = elset.parent
         p.sets.elements.pop(elset.name)
 
+    def remove_elements_by_id(self, ids):
+        """
+        Remove elements from element ids. Will remove elements on completion
+
+        :param ids: Pass in a
+        :type ids: int or list of ints
+        """
+        from collections.abc import Iterable
+
+        ids = list(ids) if isinstance(ids, Iterable) else [ids]
+        for id in ids:
+            if id in self._idmap.keys():
+                self._idmap.pop(id)
+        self._elements = list(self._idmap.values())
+        self._by_types = groupby(self._elements, key=attrgetter("type", "elset"))
+
     def __contains__(self, item):
         return item.id in self._idmap.keys()
 
@@ -142,7 +158,7 @@ class FemElements:
         return FemElements(result) if isinstance(index, slice) else result
 
     def __add__(self, other):
-        return FemElements(chain(self.elements, other.elements), self._fem_obj)
+        return FemElements(chain.from_iterable([self.elements, other.elements]), self._fem_obj)
 
     def __repr__(self):
         data = {}
@@ -189,14 +205,14 @@ class FemElements:
             ln = global_2_local_nodes([locx, locy], origin, el.nodes)
             x, y, z = list(zip(*ln))
             area = poly_area(x, y)
-            vol = t * area
-            mass = vol * el.fem_sec.material.model.rho
+            vol_ = t * area
+            mass = vol_ * el.fem_sec.material.model.rho
             mass_per_node = mass / len(el.nodes)
 
             # Have not added offset to fem_section yet
             # adjusted_nodes = [e.p+t*normal for e in el.nodes]
 
-            return mass_per_node, [e for e in el.nodes], vol
+            return mass_per_node, [e for e in el.nodes], vol_
 
         def calc_bm_elem(el):
             """
@@ -205,13 +221,13 @@ class FemElements:
             :type el: ada.Elem
             """
             el.fem_sec.section.properties.calculate()
-            nodes = el.fem_sec.get_offset_coords()
-            elem_len = vector_length(nodes[-1] - nodes[0])
-            vol = el.fem_sec.section.properties.Ax * elem_len
-            mass = vol * el.fem_sec.material.model.rho
+            nodes_ = el.fem_sec.get_offset_coords()
+            elem_len = vector_length(nodes_[-1] - nodes_[0])
+            vol_ = el.fem_sec.section.properties.Ax * elem_len
+            mass = vol_ * el.fem_sec.material.model.rho
             mass_per_node = mass / 2
 
-            return mass_per_node, [el.nodes[0], el.nodes[-1]], vol
+            return mass_per_node, [el.nodes[0], el.nodes[-1]], vol_
 
         def calc_mass_elem(el):
             """
@@ -222,9 +238,9 @@ class FemElements:
             if el.mass_props.type != "MASS":
                 raise NotImplementedError(f'Mass type "{el.mass_props.type}" is not yet implemented')
             mass = el.mass_props.mass
-            nodes = el.nodes
-            vol = 0.0
-            return mass, nodes, vol
+            nodes_ = el.nodes
+            vol_ = 0.0
+            return mass, nodes_, vol_
 
         sh = list(chain(map(calc_sh_elem, self.shell)))
         bm = list(chain(map(calc_bm_elem, self.beams)))
@@ -253,33 +269,45 @@ class FemElements:
 
         return cogx, cogy, cogz, tot_mass, tot_vol, sh_mass, bm_mass, no_mass
 
+    @property
+    def max_el_id(self):
+        return max(self._idmap.keys())
+
     @property
     def elements(self):
         return self._elements
 
     @property
     def shell(self):
-        from ada.fem import Elem
+        from ada.fem import ElemShapes
 
         skipel = ["MASS", "SPRING1"]
-        return filter(lambda x: x.type not in skipel and x.type in Elem.shell, self._elements)
+        return filter(lambda x: x.type not in skipel and x.type in ElemShapes.shell, self._elements)
 
     @property
     def beams(self):
-        from ada.fem import Elem
+        from ada.fem import ElemShapes
 
         skipel = ["MASS", "SPRING1"]
-        return filter(lambda x: x.type not in skipel and x.type in Elem.beam, self._elements)
+        return filter(lambda x: x.type not in skipel and x.type in ElemShapes.beam, self._elements)
 
     @property
     def connectors(self):
-        from ada.fem import Elem
+        """
+
+        :return: Connector elements (lazy iterator)
+        """
+        from ada.fem import ElemShapes
 
         skipel = ["MASS", "SPRING1"]
-        return filter(lambda x: x.type not in skipel and x.type in Elem.connectors, self._elements)
+        return filter(lambda x: x.type not in skipel and x.type in ElemShapes.connectors, self._elements)
 
     @property
     def masses(self):
+        """
+
+        :return: Mass elements (lazy iterator)
+        """
         from ada.fem import Mass
 
         return filter(lambda x: x.type in Mass._valid_types, self._elements)
@@ -288,7 +316,8 @@ class FemElements:
     def edges(self):
         """
 
-        :return:
+
+        :return: List of edges for visualization for all elements
         """
 
         def grab_nodes(elem):
@@ -307,7 +336,7 @@ class FemElements:
     def edges_alt(self):
         """
 
-        :return:
+        :return: List of edges for visualization for all elements (alternative implementation)
         """
 
         def grab_ids(elem):
@@ -406,10 +435,12 @@ class FemSections:
 
         :param fem_sec:
         :type fem_sec: ada.fem.FemSection
+        :param mat_repo:
+        :type mat_repo: ada.core.containers.Materials
         """
 
         if type(fem_sec.material) is str:
-            fem_sec._material = mat_repo[fem_sec.material]
+            fem_sec._material = mat_repo.get_by_name(fem_sec.material)
 
     def _map_elsets(self, fem_sec, elset_repo):
         """
@@ -547,6 +578,19 @@ class FemSets:
         if len(self._sets) > 0:
             self.link_data()
 
+    def add_references(self):
+        """
+        Add reference to the containing FemSet for each member (node or element)
+
+        :return:
+        """
+
+        def _map_ref(el, fem_set):
+            el.refs.append(fem_set)
+
+        for _set in self._sets:
+            [_map_ref(m, _set) for m in _set.members]
+
     @staticmethod
     def is_nset(fs):
         return True if fs.type == "nset" else False
@@ -555,7 +599,7 @@ class FemSets:
     def is_elset(fs):
         return True if fs.type == "elset" else False
 
-    def _map_members(self, fem_set):
+    def _instantiate_all_members(self, fem_set):
         """
 
         :param fem_set:
@@ -600,7 +644,7 @@ class FemSets:
         return fem_set
 
     def link_data(self):
-        list(map(self._map_members, self._sets))
+        list(map(self._instantiate_all_members, self._sets))
 
     def _assemble_sets(self, set_type):
         elsets = dict()
@@ -608,7 +652,7 @@ class FemSets:
             if elset.name not in elsets.keys():
                 elsets[elset.name] = elset
             else:
-                self._map_members(elset)
+                self._instantiate_all_members(elset)
                 elsets[elset.name] += elset
         return elsets
 
@@ -744,4 +788,4 @@ class FemSets:
             self._nomap[fe_set.name] = fe_set
         if fe_set.parent is None:
             fe_set.parent = self._fem_obj
-        self._map_members(fe_set)
+        self._instantiate_all_members(fe_set)
